@@ -4,7 +4,7 @@ use warnings;
 use 5.012000;
 use utf8;
 use feature 'unicode_strings';
-use version 0.77; our $VERSION = version->declare('v0.0.1_009');
+use version 0.77; our $VERSION = version->declare('v0.0.1_010');
 use Lingua::LO::NLP::Syllabify;
 use Lingua::LO::NLP::Analyze;
 use Lingua::LO::NLP::Romanize;
@@ -106,14 +106,14 @@ sub analyze_syllable {
 
     $object-E<gt>romanize($lao, %options);
 
-Returns a romanized version of the text passed in as C<$lao>. See L<Lingua::LO::NLP::Romanize/new> for options. If you don't pass in I<any> options, the defaults are
-C<variant =E<gt> 'PCGN'> and C<hyphenate =E<gt> 1>.
+Returns a romanized version of the text passed in as C<$lao>. See
+L<Lingua::LO::NLP::Romanize/new> for options. If you don't pass in I<any>
+options, the default is C<variant =E<gt> 'PCGN'>.
 
 =cut
 sub romanize {
     my (undef, $lao, %options) = @_;
     $options{variant} //= 'PCGN';
-    $options{hyphenate} //= 1;
     return Lingua::LO::NLP::Romanize->new(%options)->romanize( $lao );
 }
 
@@ -121,3 +121,20 @@ sub romanize {
 
 L<Lingua::LO::Romanize> is the module that inspired this one. It has some
 issues with ambiguous syllable boundaries as in "ໃນວົງ" though.
+
+=head1 AUTHOR
+
+Matthias Bethke, E<lt>matthias@towiski.deE<gt>
+
+=head1 COPYRIGHT AND LICENSE
+
+Copyright (C) 2016 by Matthias Bethke
+
+This library is free software; you can redistribute it and/or modify it under
+the same terms as Perl itself, either Perl version 5.14.2 or, at your option,
+any later version of Perl 5 you may have available. Significant portions of the
+code are (C) PostgreSQL Global Development Group and The Regents of the
+University of California. All modified versions must retain the file COPYRIGHT
+included in the distribution.
+
+=cut
